==> eiffelstudio-18.01.10.1424.tar: F_code/C5/gr232.c <==
/*
 * Code for class GRAPHICAL_WIZARD_DIRECTORY_QUESTION
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gr232.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.initialize */
void F476_4527 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,Current);
	RTLR(4,loc3);
	RTLR(5,loc4);
	RTLIU(6);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1076, 0x01).id, 1076, _OBJSIZ_6_3_0_1_0_0_0_0_);
	F1032_8649(RTCW(tr1));
	loc1 = (EIF_REFERENCE) tr1;
	F1075_9321(RTCW(loc1), ((EIF_INTEGER_32) 5L));
	tr1 = RTLNS(eif_new_type(1094, 0x01).id, 1094, _OBJSIZ_5_2_0_1_0_0_0_0_);
	F1060_9031(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_2_));
	loc2 = (EIF_REFERENCE) tr1;
	RTAR(Current, loc2);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) loc2;
	F89_2450(Current, loc2);
	F1068_9180(RTCW(loc1), loc2);
	F1075_9324(RTCW(loc1), loc2);
	tr1 = RTLNSMART(eif_new_type(1077, 1).id);
	F1078_9331(RTCW(tr1));
	loc3 = (EIF_REFERENCE) tr1;
	F1078_9349(RTCW(loc3));
	RTAR(Current, loc3);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) loc3;
	F1068_9180(RTCW(loc1), loc3);
	F1075_9324(RTCW(loc1), loc3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		tr1 = RTLNS(eif_new_type(1094, 0x01).id, 1094, _OBJSIZ_5_2_0_1_0_0_0_0_);
		F1060_9031(RTCW(tr1), loc4);
		loc2 = (EIF_REFERENCE) tr1;
		F89_2454(Current, loc2);
		F473_4510(Current, loc2, loc1);
	}
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) loc1;
	RTLE;
}

/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.widget */
EIF_REFERENCE F476_4528 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.input_widget */
EIF_REFERENCE F476_4529 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.title_widget */
EIF_REFERENCE F476_4530 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
}


/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.text */
EIF_REFERENCE F476_4531 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	Result = F1078_9339(RTCW(tr1));
	RTLE;
	return Result;
}

/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.set_text */
void F476_4533 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 == NULL)) {
		F476_4535(Current, NULL);
	} else {
		tr1 = RTLNS(eif_new_type(868, 0x01).id, 868, _OBJSIZ_2_1_0_0_0_0_0_0_);
		F869_6810(RTCW(tr1), arg1);
		F476_4535(Current, tr1);
	}
	RTLE;
}

/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.set_value */
void F476_4535 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 == NULL)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr2 = RTMS_EX_H("",0,0);
		F1078_9343(RTCW(tr1), tr2);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr2 = F869_6849(RTCW(arg1));
		F1078_9343(RTCW(tr1), tr2);
	}
	RTLE;
}

void EIF_Minit232 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C5/gr232.c <==
/*
 * Code for class GRAPHICAL_WIZARD_STRING_QUESTION
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gr232.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GRAPHICAL_WIZARD_STRING_QUESTION}.initialize */
void F476_4528 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,Current);
	RTLR(4,loc3);
	RTLR(5,loc4);
	RTLIU(6);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1076, 0x01).id, 1076, _OBJSIZ_6_3_0_1_0_0_0_0_);
	F1032_8651(RTCW(tr1));
	loc1 = (EIF_REFERENCE) tr1;
	F1075_9323(RTCW(loc1), ((EIF_INTEGER_32) 5L));
	tr1 = RTLNS(eif_new_type(1094, 0x01).id, 1094, _OBJSIZ_5_2_0_1_0_0_0_0_);
	F1060_9033(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_2_));
	loc2 = (EIF_REFERENCE) tr1;
	RTAR(Current, loc2);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) loc2;
	F89_2450(Current, loc2);
	F1068_9182(RTCW(loc1), loc2);
	F1075_9326(RTCW(loc1), loc2);
	tr1 = RTLNSMART(eif_new_type(1098, 1).id);
	F1032_8651(RTCW(tr1));
	loc3 = (EIF_REFERENCE) tr1;
	RTAR(Current, loc3);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) loc3;
	F1068_9182(RTCW(loc1), loc3);
	F1075_9326(RTCW(loc1), loc3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		tr1 = RTLNS(eif_new_type(1094, 0x01).id, 1094, _OBJSIZ_5_2_0_1_0_0_0_0_);
		F1060_9033(RTCW(tr1), loc4);
		loc2 = (EIF_REFERENCE) tr1;
		F89_2454(Current, loc2);
		F473_4510(Current, loc2, loc1);
	}
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) loc1;
	RTLE;
}

/* {GRAPHICAL_WIZARD_STRING_QUESTION}.widget */
EIF_REFERENCE F476_4529 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


/* {GRAPHICAL_WIZARD_STRING_QUESTION}.input_widget */
EIF_REFERENCE F476_4530 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {GRAPHICAL_WIZARD_STRING_QUESTION}.title_widget */
EIF_REFERENCE F476_4531 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
}


/* {GRAPHICAL_WIZARD_STRING_QUESTION}.text */
EIF_REFERENCE F476_4532 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	Result = F1060_9034(RTCW(tr1));
	RTLE;
	return Result;
}

/* {GRAPHICAL_WIZARD_STRING_QUESTION}.set_text */
void F476_4534 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F476_4535(Current, arg1);
}

/* {GRAPHICAL_WIZARD_STRING_QUESTION}.set_value */
void F476_4535 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 == NULL)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr2 = RTMS_EX_H("",0,0);
		F1060_9035(RTCW(tr1), tr2);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		F1060_9035(RTCW(tr1), arg1);
	}
	RTLE;
}

void EIF_Minit232 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
